Module blaxel.models.agent_chain
================================

Classes
-------

`AgentChain(description: blaxel.types.Unset | str = <blaxel.types.Unset object>, enabled: blaxel.types.Unset | bool = <blaxel.types.Unset object>, name: blaxel.types.Unset | str = <blaxel.types.Unset object>, prompt: blaxel.types.Unset | str = <blaxel.types.Unset object>)`
:   Agent chain configuration
    
    Attributes:
        description (Union[Unset, str]): Description of the agent in case you want to override the default one
        enabled (Union[Unset, bool]): Whether the agent chain is enabled
        name (Union[Unset, str]): The name of the agent to chain to
        prompt (Union[Unset, str]): Prompt of the agent in case you want to override the default one
    
    Method generated by attrs for class AgentChain.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties: dict[str, typing.Any]`
    :

    `description: blaxel.types.Unset | str`
    :

    `enabled: blaxel.types.Unset | bool`
    :

    `name: blaxel.types.Unset | str`
    :

    `prompt: blaxel.types.Unset | str`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :